aboutsummaryrefslogtreecommitdiff
path: root/bbot/agent.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'bbot/agent.cxx')
-rw-r--r--bbot/agent.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/bbot/agent.cxx b/bbot/agent.cxx
index 432e53a..683bd73 100644
--- a/bbot/agent.cxx
+++ b/bbot/agent.cxx
@@ -110,7 +110,7 @@ bootstrap_machine (const dir_path& md,
// Start the TFTP server (server chroot is --tftp). Map:
//
// GET requests to .../toolchain/<name>/*
// PUT requests to .../bootstrap/<name>/*
//
auto_rmdir arm ((dir_path (ops.tftp ()) /= "bootstrap") /= tc_name);
@@ -121,7 +121,7 @@ bootstrap_machine (const dir_path& md,
path mf (arm.path () / "manifest");
try_rmfile (mf);
- tftp_server tftpd ("Gr ^/?(.+)$ /toolchain/" + tc_name + "/\\1\n" +
+ tftp_server tftpd ("Gr ^/?(.+)$ /toolchains/" + tc_name + "/\\1\n" +
"Pr ^/?(.+)$ /bootstrap/" + tc_name + "/\\1\n");
l3 ([&]{trace << "tftp server on port " << tftpd.port ();});
@@ -110,7 +110,7 @@ bootstrap_machine (const dir_path& md,
// Start the TFTP server (server chroot is --tftp). Map:
//
- // GET requests to .../toolchain/<name>/*
+ // GET requests to .../toolchains/<name>/*
// PUT requests to .../bootstrap/<name>/*
//